@@ -4,7 +4,7 @@
    *  Secure Login Plugin
    *  By Graham Norbury <gnorbury@bondcar.com>
    *  Changes by Paul Lesneiwski <pdontthink@angrynerds.com>
-   *  v1.1 (c) 2002 (GNU GPL - see ../../COPYING)
+   *  v1.2 (c) 2002 (GNU GPL - see ../../COPYING)
    *
    *  This is a very simple plugin which enforces use of SSL security for logins.
    *
@@ -67,8 +67,30 @@ $debug = 0;
 
 
       
+      // grab port the user came in on
+      //
+      if (isset($_SERVER['SERVER_PORT']))
+         $serverPort = $_SERVER['SERVER_PORT'];
+      else
+         $serverPort = 0;
+
+
+
+      // figure out what port we should be comparing
+      //
+      if (isset($securePort))
+         $targetHttpsPort = $securePort;
+      else
+         $targetHttpsPort = '443';
+
+
+
       // Redirect browser to use https:// if the initial request was insecure
-      if ( ! isset($_SERVER['HTTPS']) &&
+      //
+// old way:
+//      if ( ! isset($_SERVER['HTTPS']) &&
+//           $secure_login_count == 0)
+      if ( $serverPort != $targetHttpsPort &&
            $secure_login_count == 0)
       {  
 
@@ -89,18 +111,32 @@ $debug = 0;
             $newRequestHost = $requestHost;
           
             
+         $pathURI = $_SERVER['REQUEST_URI'];
+         $paramsURI = '';
+         if (preg_match('/(.*)\?(.*)/', $_SERVER['REQUEST_URI'], $matches))
+         {
+            if (isset($matches[1])) $pathURI = $matches[1];
+            if (isset($matches[2])) $paramsURI = $matches[2];
+         }
+
+
          $location = 'https://' 
-                   . $newRequestHost . $_SERVER['REQUEST_URI'] . '?secure_login=yes';
+                   . $newRequestHost . $pathURI . '?secure_login=yes';
          
          if (!empty($allVirtualDomainsUnderOneSSLHost))
             $location = 'https://' . $allVirtualDomainsUnderOneSSLHost  
-                      . $newRequestHost . $_SERVER['REQUEST_URI'] . '?secure_login=yes';
+                      . $newRequestHost . $pathURI . '?secure_login=yes';
          
+         if (!empty($paramsURI))
+            $location = $location . '&' . $paramsURI;
+
          header("Location: $location");
          exit();
 
       }
-      else if (isset($_SERVER['HTTPS'])) 
+// old way
+//      else if (isset($_SERVER['HTTPS'])) 
+      else if ( $serverPort == $targetHttpsPort )
       {
 
          if (isset($_GET['secure_login']))
@@ -130,7 +166,7 @@ $debug = 0;
    function secure_login_logout_do()
    {
 
-      global $change_back_to_http_after_login, 
+      global $change_back_to_http_after_login, $securePort,
              $remain_in_https_if_logged_in_using_https,
              $plugin_secure_login_cameInUnencrypted;
 
@@ -170,13 +206,37 @@ $debug = 0;
       // it is put in the session in redirect.php with
       // the https protocol before we get here
       //
-      global $sq_base_url;
+      global $sq_base_url, $nonStandardHttpPort;
       compatibility_sqextractGlobalVar('sq_base_url');
       $sq_base_url = str_replace('https://', 'http://', $sq_base_url);
+      if (isset($nonStandardHttpPort) && !empty($nonStandardHttpPort))
+         $sq_base_url = preg_replace('/:\d\//', ":$nonStandardHttpPort/", $sq_base_url);
+      else
+         $sq_base_url = preg_replace('/:\d\//', '', $sq_base_url);
       compatibility_sqsession_register($sq_base_url, 'sq_base_url');
 
 
-      if ( ! isset($_SERVER['HTTP']) && $secure_logoff_count == 0)
+      // grab port the user came in on
+      //
+      if (isset($_SERVER['SERVER_PORT']))
+         $serverPort = $_SERVER['SERVER_PORT'];
+      else
+         $serverPort = 0;
+
+
+
+      // figure out what port we should be comparing
+      //
+      if (isset($securePort))
+         $targetHttpsPort = $securePort;
+      else
+         $targetHttpsPort = '443';
+
+
+
+      if ( $serverPort == $targetHttpsPort && $secure_logoff_count == 0)
+// old way...
+//      if ( ! isset($_SERVER['HTTP']) && $secure_logoff_count == 0)
       { 
 
          $secure_logoff_count++; 
